==> ruby-vtk_0.1.1.orig.tar.gz: ruby-vtk-0.1.1.orig/Rendering/Rendering.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkRenderingInstantiator(void);
extern SWIGEXPORT(void) Init_vtkAbstractMapper3D(void);
extern SWIGEXPORT(void) Init_vtkAbstractPicker(void);
extern SWIGEXPORT(void) Init_vtkAbstractPropPicker(void);
extern SWIGEXPORT(void) Init_vtkAxisActor2D(void);
extern SWIGEXPORT(void) Init_vtkCamera(void);
extern SWIGEXPORT(void) Init_vtkCuller(void);
extern SWIGEXPORT(void) Init_vtkCullerCollection(void);
extern SWIGEXPORT(void) Init_vtkDirectionEncoder(void);
extern SWIGEXPORT(void) Init_vtkEncodedGradientEstimator(void);
extern SWIGEXPORT(void) Init_vtkEncodedGradientShader(void);
extern SWIGEXPORT(void) Init_vtkExporter(void);
extern SWIGEXPORT(void) Init_vtkFiniteDifferenceGradientEstimator(void);
extern SWIGEXPORT(void) Init_vtkFreeTypeFontCache(void);
extern SWIGEXPORT(void) Init_vtkFrustumCoverageCuller(void);
extern SWIGEXPORT(void) Init_vtkGraphicsFactory(void);
extern SWIGEXPORT(void) Init_vtkIVExporter(void);
extern SWIGEXPORT(void) Init_vtkImageActor(void);
extern SWIGEXPORT(void) Init_vtkImageMapper(void);
extern SWIGEXPORT(void) Init_vtkImagingFactory(void);
extern SWIGEXPORT(void) Init_vtkImporter(void);
extern SWIGEXPORT(void) Init_vtkInteractorObserver(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyle(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleFlight(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleJoystickActor(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleJoystickCamera(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleSwitch(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleTerrain(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleTrackball(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleTrackballActor(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleTrackballCamera(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleUnicam(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleUser(void);
extern SWIGEXPORT(void) Init_vtkLabeledDataMapper(void);
extern SWIGEXPORT(void) Init_vtkLight(void);
extern SWIGEXPORT(void) Init_vtkLightCollection(void);
extern SWIGEXPORT(void) Init_vtkLightKit(void);
extern SWIGEXPORT(void) Init_vtkMapper(void);
extern SWIGEXPORT(void) Init_vtkMapperCollection(void);
extern SWIGEXPORT(void) Init_vtkOBJExporter(void);
extern SWIGEXPORT(void) Init_vtkOOGLExporter(void);
extern SWIGEXPORT(void) Init_vtkOpenGLCamera(void);
extern SWIGEXPORT(void) Init_vtkOpenGLImageActor(void);
extern SWIGEXPORT(void) Init_vtkOpenGLImageMapper(void);
extern SWIGEXPORT(void) Init_vtkOpenGLLight(void);
extern SWIGEXPORT(void) Init_vtkParallelCoordinatesActor(void);
extern SWIGEXPORT(void) Init_vtkPicker(void);
extern SWIGEXPORT(void) Init_vtkPointPicker(void);
extern SWIGEXPORT(void) Init_vtkPolyDataMapper(void);
extern SWIGEXPORT(void) Init_vtkPolyDataMapper2D(void);
extern SWIGEXPORT(void) Init_vtkProp3D(void);
extern SWIGEXPORT(void) Init_vtkProp3DCollection(void);
extern SWIGEXPORT(void) Init_vtkPropPicker(void);
extern SWIGEXPORT(void) Init_vtkProperty(void);
extern SWIGEXPORT(void) Init_vtkRecursiveSphereDirectionEncoder(void);
extern SWIGEXPORT(void) Init_vtkRenderWindow(void);
extern SWIGEXPORT(void) Init_vtkRenderWindowCollection(void);
extern SWIGEXPORT(void) Init_vtkRenderWindowInteractor(void);
extern SWIGEXPORT(void) Init_vtkRendererSource(void);
extern SWIGEXPORT(void) Init_vtkScalarBarActor(void);
extern SWIGEXPORT(void) Init_vtkSelectVisiblePoints(void);
extern SWIGEXPORT(void) Init_vtkTextActor(void);
extern SWIGEXPORT(void) Init_vtkTextMapper(void);
extern SWIGEXPORT(void) Init_vtkTextProperty(void);
extern SWIGEXPORT(void) Init_vtkTexture(void);
extern SWIGEXPORT(void) Init_vtkVRMLExporter(void);
extern SWIGEXPORT(void) Init_vtkVolume(void);
extern SWIGEXPORT(void) Init_vtkVolumeCollection(void);
extern SWIGEXPORT(void) Init_vtkVolumeMapper(void);
extern SWIGEXPORT(void) Init_vtkVolumeProMapper(void);
extern SWIGEXPORT(void) Init_vtkVolumeProperty(void);
extern SWIGEXPORT(void) Init_vtkVolumeRayCastFunction(void);
extern SWIGEXPORT(void) Init_vtkVolumeRayCastIsosurfaceFunction(void);
extern SWIGEXPORT(void) Init_vtkVolumeRayCastMIPFunction(void);
extern SWIGEXPORT(void) Init_vtkVolumeRayCastMapper(void);
extern SWIGEXPORT(void) Init_vtkVolumeTextureMapper(void);
extern SWIGEXPORT(void) Init_vtkVolumeTextureMapper2D(void);
extern SWIGEXPORT(void) Init_vtkWindowToImageFilter(void);
extern SWIGEXPORT(void) Init_vtkWorldPointPicker(void);
extern SWIGEXPORT(void) Init_vtkXRenderWindowInteractor(void);
extern SWIGEXPORT(void) Init_vtkActor(void);
extern SWIGEXPORT(void) Init_vtkActorCollection(void);
extern SWIGEXPORT(void) Init_vtkAssembly(void);
extern SWIGEXPORT(void) Init_vtkCellPicker(void);
extern SWIGEXPORT(void) Init_vtkDataSetMapper(void);
extern SWIGEXPORT(void) Init_vtkFollower(void);
extern SWIGEXPORT(void) Init_vtkGenericRenderWindowInteractor(void);
extern SWIGEXPORT(void) Init_vtkImageViewer(void);
extern SWIGEXPORT(void) Init_vtkImageViewer2(void);
extern SWIGEXPORT(void) Init_vtkInteractorEventRecorder(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleImage(void);
extern SWIGEXPORT(void) Init_vtkLODActor(void);
extern SWIGEXPORT(void) Init_vtkLODProp3D(void);
extern SWIGEXPORT(void) Init_vtkOpenGLActor(void);
extern SWIGEXPORT(void) Init_vtkOpenGLFreeTypeTextMapper(void);
extern SWIGEXPORT(void) Init_vtkOpenGLPolyDataMapper(void);
extern SWIGEXPORT(void) Init_vtkOpenGLPolyDataMapper2D(void);
extern SWIGEXPORT(void) Init_vtkOpenGLProperty(void);
extern SWIGEXPORT(void) Init_vtkOpenGLRenderWindow(void);
extern SWIGEXPORT(void) Init_vtkOpenGLTexture(void);
extern SWIGEXPORT(void) Init_vtkOpenGLVolumeRayCastMapper(void);
extern SWIGEXPORT(void) Init_vtkOpenGLVolumeTextureMapper2D(void);
extern SWIGEXPORT(void) Init_vtkRenderer(void);
extern SWIGEXPORT(void) Init_vtkRendererCollection(void);
extern SWIGEXPORT(void) Init_vtkScaledTextActor(void);
extern SWIGEXPORT(void) Init_vtkVolumeRayCastCompositeFunction(void);
extern SWIGEXPORT(void) Init_vtkXOpenGLRenderWindow(void);
extern SWIGEXPORT(void) Init_vtkOpenGLRenderer(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_Rendering(void){

  Init_vtkRenderingInstantiator();
  Init_vtkAbstractMapper3D();
  Init_vtkAbstractPicker();
  Init_vtkAbstractPropPicker();
  Init_vtkAxisActor2D();
  Init_vtkCamera();
  Init_vtkCuller();
  Init_vtkCullerCollection();
  Init_vtkDirectionEncoder();
  Init_vtkEncodedGradientEstimator();
  Init_vtkEncodedGradientShader();
  Init_vtkExporter();
  Init_vtkFiniteDifferenceGradientEstimator();
  Init_vtkFreeTypeFontCache();
  Init_vtkFrustumCoverageCuller();
  Init_vtkGraphicsFactory();
  Init_vtkIVExporter();
  Init_vtkImageActor();
  Init_vtkImageMapper();
  Init_vtkImagingFactory();
  Init_vtkImporter();
  Init_vtkInteractorObserver();
  Init_vtkInteractorStyle();
  Init_vtkInteractorStyleFlight();
  Init_vtkInteractorStyleJoystickActor();
  Init_vtkInteractorStyleJoystickCamera();
  Init_vtkInteractorStyleSwitch();
  Init_vtkInteractorStyleTerrain();
  Init_vtkInteractorStyleTrackball();
  Init_vtkInteractorStyleTrackballActor();
  Init_vtkInteractorStyleTrackballCamera();
  Init_vtkInteractorStyleUnicam();
  Init_vtkInteractorStyleUser();
  Init_vtkLabeledDataMapper();
  Init_vtkLight();
  Init_vtkLightCollection();
  Init_vtkLightKit();
  Init_vtkMapper();
  Init_vtkMapperCollection();
  Init_vtkOBJExporter();
  Init_vtkOOGLExporter();
  Init_vtkOpenGLCamera();
  Init_vtkOpenGLImageActor();
  Init_vtkOpenGLImageMapper();
  Init_vtkOpenGLLight();
  Init_vtkParallelCoordinatesActor();
  Init_vtkPicker();
  Init_vtkPointPicker();
  Init_vtkPolyDataMapper();
  Init_vtkPolyDataMapper2D();
  Init_vtkProp3D();
  Init_vtkProp3DCollection();
  Init_vtkPropPicker();
  Init_vtkProperty();
  Init_vtkRecursiveSphereDirectionEncoder();
  Init_vtkRenderWindow();
  Init_vtkRenderWindowCollection();
  Init_vtkRenderWindowInteractor();
  Init_vtkRendererSource();
  Init_vtkScalarBarActor();
  Init_vtkSelectVisiblePoints();
  Init_vtkTextActor();
  Init_vtkTextMapper();
  Init_vtkTextProperty();
  Init_vtkTexture();
  Init_vtkVRMLExporter();
  Init_vtkVolume();
  Init_vtkVolumeCollection();
  Init_vtkVolumeMapper();
  Init_vtkVolumeProMapper();
  Init_vtkVolumeProperty();
  Init_vtkVolumeRayCastFunction();
  Init_vtkVolumeRayCastIsosurfaceFunction();
  Init_vtkVolumeRayCastMIPFunction();
  Init_vtkVolumeRayCastMapper();
  Init_vtkVolumeTextureMapper();
  Init_vtkVolumeTextureMapper2D();
  Init_vtkWindowToImageFilter();
  Init_vtkWorldPointPicker();
  Init_vtkXRenderWindowInteractor();
  Init_vtkActor();
  Init_vtkActorCollection();
  Init_vtkAssembly();
  Init_vtkCellPicker();
  Init_vtkDataSetMapper();
  Init_vtkFollower();
  Init_vtkGenericRenderWindowInteractor();
  Init_vtkImageViewer();
  Init_vtkImageViewer2();
  Init_vtkInteractorEventRecorder();
  Init_vtkInteractorStyleImage();
  Init_vtkLODActor();
  Init_vtkLODProp3D();
  Init_vtkOpenGLActor();
  Init_vtkOpenGLFreeTypeTextMapper();
  Init_vtkOpenGLPolyDataMapper();
  Init_vtkOpenGLPolyDataMapper2D();
  Init_vtkOpenGLProperty();
  Init_vtkOpenGLRenderWindow();
  Init_vtkOpenGLTexture();
  Init_vtkOpenGLVolumeRayCastMapper();
  Init_vtkOpenGLVolumeTextureMapper2D();
  Init_vtkRenderer();
  Init_vtkRendererCollection();
  Init_vtkScaledTextActor();
  Init_vtkVolumeRayCastCompositeFunction();
  Init_vtkXOpenGLRenderWindow();
  Init_vtkOpenGLRenderer();
}

==> ruby-vtk_0.2.0.orig.tar.gz: ruby-vtk-0.2.0.orig/Rendering/Rendering.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkRenderingInstantiator(void);
extern SWIGEXPORT(void) Init_vtkAbstractMapper3D(void);
extern SWIGEXPORT(void) Init_vtkAbstractPicker(void);
extern SWIGEXPORT(void) Init_vtkAbstractPropPicker(void);
extern SWIGEXPORT(void) Init_vtkAbstractVolumeMapper(void);
extern SWIGEXPORT(void) Init_vtkAxisActor2D(void);
extern SWIGEXPORT(void) Init_vtkCamera(void);
extern SWIGEXPORT(void) Init_vtkCuller(void);
extern SWIGEXPORT(void) Init_vtkCullerCollection(void);
extern SWIGEXPORT(void) Init_vtkDirectionEncoder(void);
extern SWIGEXPORT(void) Init_vtkEncodedGradientEstimator(void);
extern SWIGEXPORT(void) Init_vtkEncodedGradientShader(void);
extern SWIGEXPORT(void) Init_vtkExporter(void);
extern SWIGEXPORT(void) Init_vtkFiniteDifferenceGradientEstimator(void);
extern SWIGEXPORT(void) Init_vtkFreeTypeFontCache(void);
extern SWIGEXPORT(void) Init_vtkFrustumCoverageCuller(void);
extern SWIGEXPORT(void) Init_vtkGraphicsFactory(void);
extern SWIGEXPORT(void) Init_vtkIVExporter(void);
extern SWIGEXPORT(void) Init_vtkImageActor(void);
extern SWIGEXPORT(void) Init_vtkImageMapper(void);
extern SWIGEXPORT(void) Init_vtkImagingFactory(void);
extern SWIGEXPORT(void) Init_vtkImporter(void);
extern SWIGEXPORT(void) Init_vtkInteractorObserver(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyle(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleFlight(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleJoystickActor(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleJoystickCamera(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleRubberBandZoom(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleSwitch(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleTerrain(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleTrackball(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleTrackballActor(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleTrackballCamera(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleUnicam(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleUser(void);
extern SWIGEXPORT(void) Init_vtkLabeledDataMapper(void);
extern SWIGEXPORT(void) Init_vtkLight(void);
extern SWIGEXPORT(void) Init_vtkLightCollection(void);
extern SWIGEXPORT(void) Init_vtkLightKit(void);
extern SWIGEXPORT(void) Init_vtkMapper(void);
extern SWIGEXPORT(void) Init_vtkMapperCollection(void);
extern SWIGEXPORT(void) Init_vtkPicker(void);
extern SWIGEXPORT(void) Init_vtkOBJExporter(void);
extern SWIGEXPORT(void) Init_vtkOOGLExporter(void);
extern SWIGEXPORT(void) Init_vtkOpenGLCamera(void);
extern SWIGEXPORT(void) Init_vtkOpenGLImageActor(void);
extern SWIGEXPORT(void) Init_vtkOpenGLImageMapper(void);
extern SWIGEXPORT(void) Init_vtkOpenGLLight(void);
extern SWIGEXPORT(void) Init_vtkParallelCoordinatesActor(void);
extern SWIGEXPORT(void) Init_vtkPointPicker(void);
extern SWIGEXPORT(void) Init_vtkPolyDataMapper(void);
extern SWIGEXPORT(void) Init_vtkPolyDataMapper2D(void);
extern SWIGEXPORT(void) Init_vtkProp3D(void);
extern SWIGEXPORT(void) Init_vtkProp3DCollection(void);
extern SWIGEXPORT(void) Init_vtkPropPicker(void);
extern SWIGEXPORT(void) Init_vtkProperty(void);
extern SWIGEXPORT(void) Init_vtkRayCastImageDisplayHelper(void);
extern SWIGEXPORT(void) Init_vtkRecursiveSphereDirectionEncoder(void);
extern SWIGEXPORT(void) Init_vtkRenderWindow(void);
extern SWIGEXPORT(void) Init_vtkRenderWindowCollection(void);
extern SWIGEXPORT(void) Init_vtkRenderWindowInteractor(void);
extern SWIGEXPORT(void) Init_vtkRendererSource(void);
extern SWIGEXPORT(void) Init_vtkScalarBarActor(void);
extern SWIGEXPORT(void) Init_vtkSelectVisiblePoints(void);
extern SWIGEXPORT(void) Init_vtkTesting(void);
extern SWIGEXPORT(void) Init_vtkTextActor(void);
extern SWIGEXPORT(void) Init_vtkTextMapper(void);
extern SWIGEXPORT(void) Init_vtkTextProperty(void);
extern SWIGEXPORT(void) Init_vtkTexture(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridVolumeMapper(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridVolumeRayCastFunction(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridVolumeRayCastMapper(void);
extern SWIGEXPORT(void) Init_vtkVRMLExporter(void);
extern SWIGEXPORT(void) Init_vtkVolume(void);
extern SWIGEXPORT(void) Init_vtkVolumeCollection(void);
extern SWIGEXPORT(void) Init_vtkVolumeMapper(void);
extern SWIGEXPORT(void) Init_vtkVolumeProMapper(void);
extern SWIGEXPORT(void) Init_vtkVolumeProperty(void);
extern SWIGEXPORT(void) Init_vtkVolumeRayCastFunction(void);
extern SWIGEXPORT(void) Init_vtkVolumeRayCastIsosurfaceFunction(void);
extern SWIGEXPORT(void) Init_vtkVolumeRayCastMIPFunction(void);
extern SWIGEXPORT(void) Init_vtkVolumeRayCastMapper(void);
extern SWIGEXPORT(void) Init_vtkVolumeTextureMapper(void);
extern SWIGEXPORT(void) Init_vtkVolumeTextureMapper2D(void);
extern SWIGEXPORT(void) Init_vtkWindowToImageFilter(void);
extern SWIGEXPORT(void) Init_vtkWorldPointPicker(void);
extern SWIGEXPORT(void) Init_vtkXRenderWindowInteractor(void);
extern SWIGEXPORT(void) Init_vtkActor(void);
extern SWIGEXPORT(void) Init_vtkActorCollection(void);
extern SWIGEXPORT(void) Init_vtkAssembly(void);
extern SWIGEXPORT(void) Init_vtkCellPicker(void);
extern SWIGEXPORT(void) Init_vtkDataSetMapper(void);
extern SWIGEXPORT(void) Init_vtkFollower(void);
extern SWIGEXPORT(void) Init_vtkGenericRenderWindowInteractor(void);
extern SWIGEXPORT(void) Init_vtkImageViewer(void);
extern SWIGEXPORT(void) Init_vtkImageViewer2(void);
extern SWIGEXPORT(void) Init_vtkInteractorEventRecorder(void);
extern SWIGEXPORT(void) Init_vtkInteractorStyleImage(void);
extern SWIGEXPORT(void) Init_vtkLODActor(void);
extern SWIGEXPORT(void) Init_vtkLODProp3D(void);
extern SWIGEXPORT(void) Init_vtkOpenGLActor(void);
extern SWIGEXPORT(void) Init_vtkOpenGLFreeTypeTextMapper(void);
extern SWIGEXPORT(void) Init_vtkOpenGLPolyDataMapper(void);
extern SWIGEXPORT(void) Init_vtkOpenGLPolyDataMapper2D(void);
extern SWIGEXPORT(void) Init_vtkOpenGLProperty(void);
extern SWIGEXPORT(void) Init_vtkOpenGLRayCastImageDisplayHelper(void);
extern SWIGEXPORT(void) Init_vtkOpenGLRenderWindow(void);
extern SWIGEXPORT(void) Init_vtkOpenGLTexture(void);
extern SWIGEXPORT(void) Init_vtkOpenGLVolumeRayCastMapper(void);
extern SWIGEXPORT(void) Init_vtkOpenGLVolumeTextureMapper2D(void);
extern SWIGEXPORT(void) Init_vtkRenderer(void);
extern SWIGEXPORT(void) Init_vtkRendererCollection(void);
extern SWIGEXPORT(void) Init_vtkScaledTextActor(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridBunykRayCastFunction(void);
extern SWIGEXPORT(void) Init_vtkVolumeRayCastCompositeFunction(void);
extern SWIGEXPORT(void) Init_vtkXOpenGLRenderWindow(void);
extern SWIGEXPORT(void) Init_vtkOpenGLRenderer(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_Rendering(void){

  Init_vtkRenderingInstantiator();
  Init_vtkAbstractMapper3D();
  Init_vtkAbstractPicker();
  Init_vtkAbstractPropPicker();
  Init_vtkAbstractVolumeMapper();
  Init_vtkAxisActor2D();
  Init_vtkCamera();
  Init_vtkCuller();
  Init_vtkCullerCollection();
  Init_vtkDirectionEncoder();
  Init_vtkEncodedGradientEstimator();
  Init_vtkEncodedGradientShader();
  Init_vtkExporter();
  Init_vtkFiniteDifferenceGradientEstimator();
  Init_vtkFreeTypeFontCache();
  Init_vtkFrustumCoverageCuller();
  Init_vtkGraphicsFactory();
  Init_vtkIVExporter();
  Init_vtkImageActor();
  Init_vtkImageMapper();
  Init_vtkImagingFactory();
  Init_vtkImporter();
  Init_vtkInteractorObserver();
  Init_vtkInteractorStyle();
  Init_vtkInteractorStyleFlight();
  Init_vtkInteractorStyleJoystickActor();
  Init_vtkInteractorStyleJoystickCamera();
  Init_vtkInteractorStyleRubberBandZoom();
  Init_vtkInteractorStyleSwitch();
  Init_vtkInteractorStyleTerrain();
  Init_vtkInteractorStyleTrackball();
  Init_vtkInteractorStyleTrackballActor();
  Init_vtkInteractorStyleTrackballCamera();
  Init_vtkInteractorStyleUnicam();
  Init_vtkInteractorStyleUser();
  Init_vtkLabeledDataMapper();
  Init_vtkLight();
  Init_vtkLightCollection();
  Init_vtkLightKit();
  Init_vtkMapper();
  Init_vtkMapperCollection();
  Init_vtkPicker();
  Init_vtkOBJExporter();
  Init_vtkOOGLExporter();
  Init_vtkOpenGLCamera();
  Init_vtkOpenGLImageActor();
  Init_vtkOpenGLImageMapper();
  Init_vtkOpenGLLight();
  Init_vtkParallelCoordinatesActor();
  Init_vtkPointPicker();
  Init_vtkPolyDataMapper();
  Init_vtkPolyDataMapper2D();
  Init_vtkProp3D();
  Init_vtkProp3DCollection();
  Init_vtkPropPicker();
  Init_vtkProperty();
  Init_vtkRayCastImageDisplayHelper();
  Init_vtkRecursiveSphereDirectionEncoder();
  Init_vtkRenderWindow();
  Init_vtkRenderWindowCollection();
  Init_vtkRenderWindowInteractor();
  Init_vtkRendererSource();
  Init_vtkScalarBarActor();
  Init_vtkSelectVisiblePoints();
  Init_vtkTesting();
  Init_vtkTextActor();
  Init_vtkTextMapper();
  Init_vtkTextProperty();
  Init_vtkTexture();
  Init_vtkUnstructuredGridVolumeMapper();
  Init_vtkUnstructuredGridVolumeRayCastFunction();
  Init_vtkUnstructuredGridVolumeRayCastMapper();
  Init_vtkVRMLExporter();
  Init_vtkVolume();
  Init_vtkVolumeCollection();
  Init_vtkVolumeMapper();
  Init_vtkVolumeProMapper();
  Init_vtkVolumeProperty();
  Init_vtkVolumeRayCastFunction();
  Init_vtkVolumeRayCastIsosurfaceFunction();
  Init_vtkVolumeRayCastMIPFunction();
  Init_vtkVolumeRayCastMapper();
  Init_vtkVolumeTextureMapper();
  Init_vtkVolumeTextureMapper2D();
  Init_vtkWindowToImageFilter();
  Init_vtkWorldPointPicker();
  Init_vtkXRenderWindowInteractor();
  Init_vtkActor();
  Init_vtkActorCollection();
  Init_vtkAssembly();
  Init_vtkCellPicker();
  Init_vtkDataSetMapper();
  Init_vtkFollower();
  Init_vtkGenericRenderWindowInteractor();
  Init_vtkImageViewer();
  Init_vtkImageViewer2();
  Init_vtkInteractorEventRecorder();
  Init_vtkInteractorStyleImage();
  Init_vtkLODActor();
  Init_vtkLODProp3D();
  Init_vtkOpenGLActor();
  Init_vtkOpenGLFreeTypeTextMapper();
  Init_vtkOpenGLPolyDataMapper();
  Init_vtkOpenGLPolyDataMapper2D();
  Init_vtkOpenGLProperty();
  Init_vtkOpenGLRayCastImageDisplayHelper();
  Init_vtkOpenGLRenderWindow();
  Init_vtkOpenGLTexture();
  Init_vtkOpenGLVolumeRayCastMapper();
  Init_vtkOpenGLVolumeTextureMapper2D();
  Init_vtkRenderer();
  Init_vtkRendererCollection();
  Init_vtkScaledTextActor();
  Init_vtkUnstructuredGridBunykRayCastFunction();
  Init_vtkVolumeRayCastCompositeFunction();
  Init_vtkXOpenGLRenderWindow();
  Init_vtkOpenGLRenderer();
}
